==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/mobilepacketcore/kotlin/ObservabilityService.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilepacketcore.kotlin

import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.OperationalStatusResponse
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.QualifiedComponentDeploymentParametersResponse
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.OperationalStatusResponse.Companion.toKotlin as operationalStatusResponseToKotlin
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.QualifiedComponentDeploymentParametersResponse.Companion.toKotlin as qualifiedComponentDeploymentParametersResponseToKotlin
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [ObservabilityService].
 */
@PulumiTagMarker
public class ObservabilityServiceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ObservabilityServiceArgs = ObservabilityServiceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ObservabilityServiceArgsBuilder.() -> Unit) {
        val builder = ObservabilityServiceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ObservabilityService {
        val builtJavaResource =
            com.pulumi.azurenative.mobilepacketcore.ObservabilityService(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ObservabilityService(builtJavaResource)
    }
}

/**
 * Azure for Operators 5G Core Observability Service Resource
 * Azure REST API version: 2023-10-15-preview.
 * ## Example Usage
 * ### ObservabilityServices_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var observabilityService = new AzureNative.MobilePacketCore.ObservabilityService("observabilityService", new()
 *     {
 *         ClusterService = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.MobilePacketCore/clusterServices/byoCluster",
 *         ComponentParameters = new[]
 *         {
 *             new AzureNative.MobilePacketCore.Inputs.QualifiedComponentDeploymentParametersArgs
 *             {
 *                 Parameters = "{\"global\": {\"registry\": {\"docker\": []}}}",
 *                 Secrets = "{\"global\": {\"secret\": {\"secretValue\": []}}}",
 *                 Type = "fed-crds",
 *             },
 *         },
 *         Location = "eastus",
 *         ObservabilityServiceName = "observabilityService1",
 *         ResourceGroupName = "rg1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/mobilepacketcore/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := mobilepacketcore.NewObservabilityService(ctx, "observabilityService", &mobilepacketcore.ObservabilityServiceArgs{
 * 			ClusterService: pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.MobilePacketCore/clusterServices/byoCluster"),
 * 			ComponentParameters: []mobilepacketcore.QualifiedComponentDeploymentParametersArgs{
 * 				{
 * 					Parameters: pulumi.String("{\"global\": {\"registry\": {\"docker\": []}}}"),
 * 					Secrets:    pulumi.String("{\"global\": {\"secret\": {\"secretValue\": []}}}"),
 * 					Type:       pulumi.String("fed-crds"),
 * 				},
 * 			},
 * 			Location:                 pulumi.String("eastus"),
 * 			ObservabilityServiceName: pulumi.String("observabilityService1"),
 * 			ResourceGroupName:        pulumi.String("rg1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.mobilepacketcore.ObservabilityService;
 * import com.pulumi.azurenative.mobilepacketcore.ObservabilityServiceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var observabilityService = new ObservabilityService("observabilityService", ObservabilityServiceArgs.builder()
 *             .clusterService("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.MobilePacketCore/clusterServices/byoCluster")
 *             .componentParameters(Map.ofEntries(
 *                 Map.entry("parameters", "{\"global\": {\"registry\": {\"docker\": []}}}"),
 *                 Map.entry("secrets", "{\"global\": {\"secret\": {\"secretValue\": []}}}"),
 *                 Map.entry("type", "fed-crds")
 *             ))
 *             .location("eastus")
 *             .observabilityServiceName("observabilityService1")
 *             .resourceGroupName("rg1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:mobilepacketcore:ObservabilityService observabilityService1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MobilePacketCore/observabilityServices/{observabilityServiceName}
 * ```
 */
public class ObservabilityService internal constructor(
    override val javaResource: com.pulumi.azurenative.mobilepacketcore.ObservabilityService,
) : KotlinCustomResource(javaResource, ObservabilityServiceMapper) {
    /**
     * Reference to cluster where the observability components are deployed
     */
    public val clusterService: Output<String>
        get() = javaResource.clusterService().applyValue({ args0 -> args0 })

    /**
     * Azure for Operators 5G Core Observability component parameters.  One set per component type
     */
    public val componentParameters: Output<List<QualifiedComponentDeploymentParametersResponse>>
        get() = javaResource.componentParameters().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> qualifiedComponentDeploymentParametersResponseToKotlin(args0) })
            })
        })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Operational status
     */
    public val operationalStatus: Output<OperationalStatusResponse>
        get() = javaResource.operationalStatus().applyValue({ args0 ->
            args0.let({ args0 ->
                operationalStatusResponseToKotlin(args0)
            })
        })

    /**
     * The status of the last operation.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Release version. This is inherited from the cluster
     */
    public val releaseVersion: Output<String>
        get() = javaResource.releaseVersion().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ObservabilityServiceMapper : ResourceMapper<ObservabilityService> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.mobilepacketcore.ObservabilityService::class == javaResource::class

    override fun map(javaResource: Resource): ObservabilityService = ObservabilityService(
        javaResource
            as com.pulumi.azurenative.mobilepacketcore.ObservabilityService,
    )
}

/**
 * @see [ObservabilityService].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ObservabilityService].
 */
public suspend fun observabilityService(
    name: String,
    block: suspend ObservabilityServiceResourceBuilder.() -> Unit,
): ObservabilityService {
    val builder = ObservabilityServiceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ObservabilityService].
 * @param name The _unique_ name of the resulting resource.
 */
public fun observabilityService(name: String): ObservabilityService {
    val builder = ObservabilityServiceResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/mobilepacketcore/kotlin/ObservabilityService.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilepacketcore.kotlin

import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.OperationalStatusResponse
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.QualifiedComponentDeploymentParametersResponse
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.OperationalStatusResponse.Companion.toKotlin as operationalStatusResponseToKotlin
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.QualifiedComponentDeploymentParametersResponse.Companion.toKotlin as qualifiedComponentDeploymentParametersResponseToKotlin
import com.pulumi.azurenative.mobilepacketcore.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [ObservabilityService].
 */
@PulumiTagMarker
public class ObservabilityServiceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ObservabilityServiceArgs = ObservabilityServiceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ObservabilityServiceArgsBuilder.() -> Unit) {
        val builder = ObservabilityServiceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ObservabilityService {
        val builtJavaResource =
            com.pulumi.azurenative.mobilepacketcore.ObservabilityService(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ObservabilityService(builtJavaResource)
    }
}

/**
 * Azure for Operators 5G Core Observability Service Resource
 * Azure REST API version: 2023-10-15-preview.
 * ## Example Usage
 * ### ObservabilityServices_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var observabilityService = new AzureNative.MobilePacketCore.ObservabilityService("observabilityService", new()
 *     {
 *         ClusterService = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.MobilePacketCore/clusterServices/byoCluster",
 *         ComponentParameters = new[]
 *         {
 *             new AzureNative.MobilePacketCore.Inputs.QualifiedComponentDeploymentParametersArgs
 *             {
 *                 Parameters = "{\"global\": {\"registry\": {\"docker\": []}}}",
 *                 Secrets = "{\"global\": {\"secret\": {\"secretValue\": []}}}",
 *                 Type = "fed-crds",
 *             },
 *         },
 *         Location = "eastus",
 *         ObservabilityServiceName = "observabilityService1",
 *         ResourceGroupName = "rg1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/mobilepacketcore/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := mobilepacketcore.NewObservabilityService(ctx, "observabilityService", &mobilepacketcore.ObservabilityServiceArgs{
 * 			ClusterService: pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.MobilePacketCore/clusterServices/byoCluster"),
 * 			ComponentParameters: mobilepacketcore.QualifiedComponentDeploymentParametersArray{
 * 				&mobilepacketcore.QualifiedComponentDeploymentParametersArgs{
 * 					Parameters: pulumi.String("{\"global\": {\"registry\": {\"docker\": []}}}"),
 * 					Secrets:    pulumi.String("{\"global\": {\"secret\": {\"secretValue\": []}}}"),
 * 					Type:       pulumi.String("fed-crds"),
 * 				},
 * 			},
 * 			Location:                 pulumi.String("eastus"),
 * 			ObservabilityServiceName: pulumi.String("observabilityService1"),
 * 			ResourceGroupName:        pulumi.String("rg1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.mobilepacketcore.ObservabilityService;
 * import com.pulumi.azurenative.mobilepacketcore.ObservabilityServiceArgs;
 * import com.pulumi.azurenative.mobilepacketcore.inputs.QualifiedComponentDeploymentParametersArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var observabilityService = new ObservabilityService("observabilityService", ObservabilityServiceArgs.builder()
 *             .clusterService("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.MobilePacketCore/clusterServices/byoCluster")
 *             .componentParameters(QualifiedComponentDeploymentParametersArgs.builder()
 *                 .parameters("{\"global\": {\"registry\": {\"docker\": []}}}")
 *                 .secrets("{\"global\": {\"secret\": {\"secretValue\": []}}}")
 *                 .type("fed-crds")
 *                 .build())
 *             .location("eastus")
 *             .observabilityServiceName("observabilityService1")
 *             .resourceGroupName("rg1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:mobilepacketcore:ObservabilityService observabilityService1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MobilePacketCore/observabilityServices/{observabilityServiceName}
 * ```
 */
public class ObservabilityService internal constructor(
    override val javaResource: com.pulumi.azurenative.mobilepacketcore.ObservabilityService,
) : KotlinCustomResource(javaResource, ObservabilityServiceMapper) {
    /**
     * Reference to cluster where the observability components are deployed
     */
    public val clusterService: Output<String>
        get() = javaResource.clusterService().applyValue({ args0 -> args0 })

    /**
     * Azure for Operators 5G Core Observability component parameters.  One set per component type
     */
    public val componentParameters: Output<List<QualifiedComponentDeploymentParametersResponse>>
        get() = javaResource.componentParameters().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> qualifiedComponentDeploymentParametersResponseToKotlin(args0) })
            })
        })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Operational status
     */
    public val operationalStatus: Output<OperationalStatusResponse>
        get() = javaResource.operationalStatus().applyValue({ args0 ->
            args0.let({ args0 ->
                operationalStatusResponseToKotlin(args0)
            })
        })

    /**
     * The status of the last operation.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Release version. This is inherited from the cluster
     */
    public val releaseVersion: Output<String>
        get() = javaResource.releaseVersion().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ObservabilityServiceMapper : ResourceMapper<ObservabilityService> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.mobilepacketcore.ObservabilityService::class == javaResource::class

    override fun map(javaResource: Resource): ObservabilityService = ObservabilityService(
        javaResource
            as com.pulumi.azurenative.mobilepacketcore.ObservabilityService,
    )
}

/**
 * @see [ObservabilityService].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ObservabilityService].
 */
public suspend fun observabilityService(
    name: String,
    block: suspend ObservabilityServiceResourceBuilder.() -> Unit,
): ObservabilityService {
    val builder = ObservabilityServiceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ObservabilityService].
 * @param name The _unique_ name of the resulting resource.
 */
public fun observabilityService(name: String): ObservabilityService {
    val builder = ObservabilityServiceResourceBuilder()
    builder.name(name)
    return builder.build()
}
